@@ -446,88 +446,6 @@ void dumpNtopFlows(FILE *fDescr, char* options, int actualDeviceId) {
 
 /* ********************************** */
 
-void dumpNtopTrafficMatrix(FILE *fDescr, char* options, int actualDeviceId) {
-  char key[64];
-  unsigned int numEntries=0, lang=DEFAULT_FLAG_LANGUAGE;
-  int i=0, j;
-  char buf[LEN_GENERAL_WORK_BUFFER];
-
-  memset(key, 0, sizeof(key));
-
-  if(options != NULL) {
-    /* language now defined into "languages[]" */
-    char *tmpStr, *strtokState;
-
-    tmpStr = strtok_r(options, "&", &strtokState);
-
-    while(tmpStr != NULL) {
-      while((tmpStr[i] != '\0') && (tmpStr[i] != '='))
-	i++;
-
-      /* If argument contains "language=something", then
-	 look in the table "languages" of known language for
-	 the choosen language.
-      */
-
-      if(tmpStr[i] == '=') {
-	tmpStr[i] = 0;
-
-	if(strcasecmp(tmpStr, "language") == 0) {
-	  lang = DEFAULT_FLAG_LANGUAGE;
-	  for(j=1;j < MAX_FLAG_LANGUGE;j++) {
-	    if(strcasecmp(&tmpStr[i+1], languages[j]) == 0) {
-	      lang = j;
-	      break;
-	    }
-	  }
-	}
-      }
-
-      tmpStr = strtok_r(NULL, "&", &strtokState);
-    }
-  }
-
-  /* *************************************** */
-
-  for(i=0; i<myGlobals.device[myGlobals.actualReportDeviceId].numHosts; i++)
-      for(j=0; j<myGlobals.device[myGlobals.actualReportDeviceId].numHosts; j++) {
-	if(i != j) {
-	  int idx = i*myGlobals.device[myGlobals.actualReportDeviceId].numHosts+j;
-
-	  if(myGlobals.device[myGlobals.actualReportDeviceId].ipTrafficMatrix[idx] == NULL)
-	    continue;
-
-	if(myGlobals.device[myGlobals.actualReportDeviceId].ipTrafficMatrix[idx]->bytesSent.value > 0) {
-	    if(numEntries == 0) initWriteArray(fDescr, lang);
-
-	    safe_snprintf(__FILE__, __LINE__, buf, sizeof(buf), "%s_%s",
-			myGlobals.device[myGlobals.actualReportDeviceId].ipTrafficMatrixHosts[i]->hostNumIpAddress,
-			myGlobals.device[myGlobals.actualReportDeviceId].ipTrafficMatrixHosts[j]->hostNumIpAddress);
-
-	  REPEAT_MATRIX:
-	    initWriteKey(fDescr, lang,  "", buf, numEntries);
-	    wrtLlongItm(fDescr, lang, "\t", "pkts",
-			myGlobals.device[myGlobals.actualReportDeviceId].ipTrafficMatrix[idx]->pktsSent,
-			',', numEntries);
-	    wrtLlongItm(fDescr, lang, "\t", "bytes",
-			myGlobals.device[myGlobals.actualReportDeviceId].ipTrafficMatrix[idx]->bytesSent,
-			',', numEntries);
-	    endWriteKey(fDescr, lang,   "", buf, ',');
-	    numEntries++;
-
-	    if((lang == FLAG_NO_LANGUAGE) && (numEntries == 1))
-	      goto REPEAT_MATRIX;
-
-	    numEntries++;
-	  }
-	}
-      }
-
-  if(numEntries > 0) endWriteArray(fDescr, lang, numEntries);
-}
-
-/* ********************************** */
-
 static void updateRefCount(HostTraffic *el, int value) {
   if(el->refCount == 0) return;
 
@@ -668,14 +586,6 @@ void dumpNtopHashes(FILE *fDescr, char* options, int actualDeviceId) {
 	  wrtStrItm(fDescr, lang, "\t", "nbDescr",      el->nonIPTraffic->nbDescr, ',', numEntries);
 	if(checkFilter(filter, "nodeType"))
 	  wrtUcharItm (fDescr, lang, "\t", "nodeType",  el->nonIPTraffic->nbNodeType, ' ', numEntries);
-	if(checkFilter(filter, "atNodeName"))
-	  wrtStrItm(fDescr, lang, "\t", "atNodeName",   el->nonIPTraffic->atNodeName, ',', numEntries);
-	if(checkFilter(filter, "atNetwork"))
-	  wrtUshortItm(fDescr, lang, "\t", "atNetwork",  el->nonIPTraffic->atNetwork, ' ', numEntries);
-	if(checkFilter(filter, "atNode"))
-	  wrtUcharItm (fDescr, lang, "\t", "atNode",    el->nonIPTraffic->atNode, ' ', numEntries);
-	if(checkFilter(filter, "ipxHostName"))
-	  wrtStrItm(fDescr, lang, "\t", "ipxHostName",  el->nonIPTraffic->ipxHostName, ',', numEntries);
       }
     }
 
@@ -854,15 +764,6 @@ void dumpNtopHashes(FILE *fDescr, char* options, int actualDeviceId) {
 	  wrtLlongItm(fDescr, lang, "\t", "stpSent", el->nonIPTraffic->stpSent, ',', numEntries);
 	if(checkFilter(filter, "stpRcvd"))
 	  wrtLlongItm(fDescr, lang, "\t", "stpRcvd", el->nonIPTraffic->stpRcvd, ',', numEntries);
-	if(checkFilter(filter, "ipxSent"))
-	  wrtLlongItm(fDescr, lang, "\t", "ipxSent", el->nonIPTraffic->ipxSent, ',', numEntries);
-	if(checkFilter(filter, "ipxRcvd"))
-	  wrtLlongItm(fDescr, lang, "\t", "ipxRcvd", el->nonIPTraffic->ipxRcvd, ',', numEntries);
-	if(checkFilter(filter, "dlcSent"))
-	  wrtLlongItm(fDescr, lang, "\t", "dlcSent", el->nonIPTraffic->dlcSent, ',', numEntries);
-	if(checkFilter(filter, "dlcRcvd"))
-	  wrtLlongItm(fDescr, lang, "\t", "dlcRcvd", el->nonIPTraffic->dlcRcvd, ',', numEntries);
-
 	if(checkFilter(filter, "arp_rarpSent"))
 	  wrtLlongItm(fDescr, lang, "\t", "arp_rarpSent",el->nonIPTraffic->arp_rarpSent, ',', numEntries);
 	if(checkFilter(filter, "arp_rarpRcvd"))
@@ -873,10 +774,6 @@ void dumpNtopHashes(FILE *fDescr, char* options, int actualDeviceId) {
 	  wrtLlongItm(fDescr, lang, "\t", "arpReplyPktsSent", el->nonIPTraffic->arpReplyPktsSent, ',', numEntries);
 	if(checkFilter(filter, "arpReplyPktsRcvd"))
 	  wrtLlongItm(fDescr, lang, "\t", "arpReplyPktsRcvd", el->nonIPTraffic->arpReplyPktsRcvd, ',', numEntries);
-	if(checkFilter(filter, "appletalkSent"))
-	  wrtLlongItm(fDescr, lang, "\t", "appletalkSent", el->nonIPTraffic->appletalkSent, ',', numEntries);
-	if(checkFilter(filter, "appletalkRcvd"))
-	  wrtLlongItm(fDescr, lang, "\t", "appletalkRcvd", el->nonIPTraffic->appletalkRcvd, ',', numEntries);
 	if(checkFilter(filter, "netbiosSent"))
 	  wrtLlongItm(fDescr, lang, "\t", "netbiosSent", el->nonIPTraffic->netbiosSent, ',', numEntries);
 	if(checkFilter(filter, "netbiosRcvd"))
@@ -1334,8 +1231,6 @@ void dumpNtopTrafficInfo(FILE *fDescr, char* options) {
     if(checkFilter(filter, "dlcBytes"))
       wrtLlongItm(fDescr, lang, "\t", "dlcBytes",myGlobals.device[i].dlcBytes, ',', numEntries);
 
-    if(checkFilter(filter, "ipxBytes"))
-      wrtLlongItm(fDescr, lang, "\t", "ipxBytes",myGlobals.device[i].ipxBytes, ',', numEntries);
     if(checkFilter(filter, "stpBytes"))
       wrtLlongItm(fDescr, lang, "\t", "stpBytes",myGlobals.device[i].stpBytes, ',', numEntries);
     if(checkFilter(filter, "ipsecBytes"))
@@ -1344,8 +1239,6 @@ void dumpNtopTrafficInfo(FILE *fDescr, char* options) {
       wrtLlongItm(fDescr, lang, "\t", "netbiosBytes",myGlobals.device[i].netbiosBytes, ',', numEntries);
     if(checkFilter(filter, "arpRarpBytes"))
       wrtLlongItm(fDescr, lang, "\t", "arpRarpBytes",myGlobals.device[i].arpRarpBytes, ',', numEntries);
-    if(checkFilter(filter, "atalkBytes"))
-      wrtLlongItm(fDescr, lang, "\t", "atalkBytes",myGlobals.device[i].atalkBytes, ',', numEntries);
     if(checkFilter(filter, "egpBytes"))
       wrtLlongItm(fDescr, lang, "\t", "egpBytes",myGlobals.device[i].egpBytes, ',', numEntries);
     if(checkFilter(filter, "greBytes"))
@@ -1396,8 +1289,6 @@ void dumpNtopTrafficInfo(FILE *fDescr, char* options) {
 	wrtLlongItm(fDescr, lang, "\t", "shortest",myGlobals.device[i].rcvdPktStats.shortest, ',', numEntries);
       if(checkFilter(filter, "longest"))
 	wrtLlongItm(fDescr, lang, "\t", "longest",myGlobals.device[i].rcvdPktStats.longest, ',', numEntries);
-      if(checkFilter(filter, "badChecksum"))
-	wrtLlongItm(fDescr, lang, "\t", "badChecksum",myGlobals.device[i].rcvdPktStats.badChecksum, ',', numEntries);
       if(checkFilter(filter, "tooLong"))
 	wrtLlongItm(fDescr, lang, "\t", "tooLong",myGlobals.device[i].rcvdPktStats.tooLong, ',', numEntries);
       if(checkFilter(filter, "peakThroughput"))
