@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1998-2010 Luca Deri <deri@ntop.org>
+ *  Copyright (C) 1998-2011 Luca Deri <deri@ntop.org>
  *
  *		 	    http://www.ntop.org/
  *
@@ -103,9 +103,7 @@ extern void printPacketStats(HostTraffic *el, int actualDeviceId);
 extern void printFcPacketStats(HostTraffic *el, int actualDeviceId);
 extern void printHostTrafficStats(HostTraffic *el, int actualDeviceId);
 extern void printFcHostTrafficStats(HostTraffic *el, int actualDeviceId);
-#ifdef INET6
 extern void printIcmpv6Stats(HostTraffic *el);
-#endif
 extern void printIcmpv4Stats(HostTraffic *el);
 extern void printHostFragmentStats(HostTraffic *el, int actualDeviceId);
 extern void printTotalFragmentStats(HostTraffic *el, int actualDeviceId);
@@ -113,17 +111,9 @@ extern HostTraffic* quickHostLink(HostSerial theSerial, int deviceId, HostTraffi
 extern void printHostContactedPeers(HostTraffic *el, int actualDeviceId);
 extern void printFcHostContactedPeers(HostTraffic *el, int actualDeviceId);
 extern char *getSessionState(IPSession *session);
-#ifdef ENABLE_FC
-extern char *getFcSessionState(FCSession *session);
-#endif
 extern void printHostSessions(HostTraffic *el, int actualDeviceId);
 extern u_short isHostHealthy(HostTraffic *el);
 extern void printHostDetailedInfo(HostTraffic *el, int actualDeviceId);
-#ifdef ENABLE_FC
-extern void printFcHostDetailedInfo(HostTraffic *el, int actualDeviceId);
-extern void printVsanDetailedInfo (u_int vsanId, int actualDeviceId);
-extern void printVsanProtocolStats (FcFabricElementHash *hash, int actualDeviceId);
-#endif
 extern void printServiceStats(char* svcName, ServiceStats* ss, short printSentStats);
 extern void printHostUsedServices(HostTraffic *el, int actualDeviceId);
 extern void printHostIcmpStats(HostTraffic *el);
@@ -141,14 +131,8 @@ extern void dumpNtopFlows(FILE *fDescr, char* options, int actualDeviceId);
 extern void dumpNtopHashes(FILE*, char*, int actualDeviceId);
 extern void dumpNtopHashIndexes(FILE*, char* options, int actualDeviceId);
 extern void dumpNtopTrafficInfo(FILE*, char* options);
-extern void dumpNtopTrafficMatrix(FILE *fDescr, char* options, int actualDeviceId);
 extern void checkHostProvidedServices(HostTraffic *el);
 extern void printHostsStats(int fingerprintRemote);
-#ifdef ENABLE_FC
-extern FcFabricElementHash *getFcFabricElementHash (u_short vsanId, int actualDeviceId);
-extern void dumpFcFabricElementHash (FcFabricElementHash **theHash, char* label,
-                                     u_char dumpLoopbackTraffic, u_char vsanHash);
-#endif
 extern void printMutexStatus(int textPrintFlag, PthreadMutex *mutexId, char *mutexName);
 
 extern void printPluginTrailer(char *left, char *middle);
@@ -206,12 +190,7 @@ extern void printHostsInfo(int sortedColumn, int revertOrder, int pageNum,
 extern void makeDot(void);
 extern void printFcHostsInfo(int sortedColumn, int revertOrder, int pageNum, int showBytes, int vsanId);
 extern void printAllSessionsHTML (char* host, int actualDeviceId, int sortedColumn,
-                                  int revertOrder, int pageNum, char *url,
-                                  int hostInfoPage);
-/* extern void printAllSessionsHTML (char* host, int actualDeviceId, int sortedColumn,
-   int revertOrder, int pageNum, char *url,
-   int hostInfoPage);
-*/
+                                  int revertOrder, int pageNum, char *url);
 extern void printLocalRoutersList(int actualDeviceId);
 extern void printIpAccounting(int remoteToLocal, int sortedColumn,
 			      int revertOrder, int pageNum);
@@ -223,41 +202,8 @@ extern void printBar(char *buf, int bufLen, unsigned short percentageS, unsigned
                      unsigned short maxPercentage, unsigned short ratio);
 extern void printIpProtocolDistribution(int mode, int revertOrder, int printGraph);
 
-#ifdef ENABLE_FC
-extern void printFcProtocolDistribution(int mode, int revertOrder, int printGraph);
-extern void printFcTrafficMatrix (u_short vsanId, u_char sent);
-extern void drawVsanStatsGraph (unsigned int deviceId);
-extern void printVSANList(unsigned int deviceId);
-extern void printFCSessions(int actualDeviceId, int sortedColumn, int revertOrder,
-                            int pageNum, char *url, HostTraffic *el);
-extern int printScsiSessionBytes (int actualDeviceId, int sortedColumn,
-                                  int revertOrder, int pageNum, char *url,
-                                  HostTraffic *el);
-extern int printScsiSessionTimes (int actualDeviceId, int sortedColumn,
-                                  int revertOrder, int pageNum, char *url,
-                                  HostTraffic *el);
-extern int printScsiSessionStatusInfo (int actualDeviceId, int sortedColumn,
-                                       int revertOrder, int pageNum, char *url,
-                                       HostTraffic *el);
-extern int printScsiSessionTmInfo (int actualDeviceId, int sortedColumn,
-                                   int revertOrder, int pageNum, char *url,
-                                   HostTraffic *el);
-extern void printScsiLunStats (HostTraffic *el, int actualDeviceId,
-                               int sortedColumn, int revertOrder,
-                               int pageNum, char *lun);
-extern void printScsiLunGraphs (HostTraffic *el, int actualDeviceId);
-extern void printFcTrafficSummary (u_short vsanId);
-extern void printFcHostsTraffic(int reportType,
-			      int sortedColumn, int revertOrder,
-			      int pageNum, char* url,
-                              LocalityDisplayPolicy showLocalityMode);
-extern void printVSANList(unsigned int deviceId);
-#endif
-
 extern void printProtoTraffic(int printGraph);
 extern void printProcessInfo(int processPid, int actualReportDeviceId);
-extern void printIpTrafficMatrix(void);
-extern void printThptStatsMatrix(int sortedColumn);
 extern void printThptStats(int sortedColumn);
 extern void printDomainStats(char* domain_domain_name, int network_mode, int communityMode, 
 			     int sortedColumn, int revertOrder, int pageNum);
@@ -298,7 +244,7 @@ extern bool processNtopPref (char *key, char *value, bool savePref,
 
 extern int printNtopLogReport(int printAsText);
 extern char* makeHostAgeStyleSpec(HostTraffic *el, char *buf, int bufSize);
-extern void edit_prefs(char *db_key, char *db_val);
+extern void edit_prefs(int postLen);
 
 /* **************************** */
 
@@ -330,11 +276,6 @@ extern char *getRowColor(void);
 extern char *makeHostLink(HostTraffic *el, short mode,
                           short cutName, short addCountryFlag,
 			  char *buf, int bufLen);
-#ifdef ENABLE_FC
-extern char *makeFcHostLink (HostTraffic *el, short mode, short cutName,
-                             short compactWWN, char *buf, int buflen);
-extern char *makeVsanLink (u_short vsanId, short mode, char *buf, int buflen);
-#endif
 extern void  buildMapLink(HostTraffic *el, char *buf, int buf_len);
 extern char *getHostName(HostTraffic *el, short cutName, char *buf, int bufLen);
 
@@ -357,15 +298,6 @@ extern void drawThptGraph(int sortedColumn);
 extern void drawGlobalProtoDistribution(void);
 extern int  drawHostsDistanceGraph(int);
 extern void drawGlobalIpProtoDistribution(void);
-#ifdef ENABLE_FC
-extern void drawGlobalFcProtoDistribution(void);
-extern void drawLunStatsBytesDistribution(HostTraffic *el);
-extern void drawLunStatsPktsDistribution(HostTraffic *el);
-extern void drawVsanStatsBytesDistribution(int deviceId);
-extern void drawVsanStatsPktsDistribution(int deviceId);
-extern void drawVsanDomainTrafficDistribution(u_short vsanId, u_char dataSent);
-extern void drawVsanSwilsProtoDistribution(u_short vsanId);
-#endif
 
 /* python.c */
 #ifdef HAVE_PYTHON
