@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1998-2010 Luca Deri <deri@ntop.org>
+ *  Copyright (C) 1998-2011 Luca Deri <deri@ntop.org>
  *
  *  			    http://www.ntop.org/
  *
@@ -174,10 +174,8 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
     
     if(theHost->nonIPTraffic != NULL)
       totTraffic.value += theHost->nonIPTraffic->stpSent.value+
-	theHost->nonIPTraffic->ipxSent.value+
 	theHost->nonIPTraffic->dlcSent.value+
 	theHost->nonIPTraffic->arp_rarpSent.value+
-	theHost->nonIPTraffic->appletalkSent.value+
 	theHost->nonIPTraffic->netbiosSent.value+
 	theHost->nonIPTraffic->otherSent.value;
 
@@ -195,10 +193,8 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 
     if(theHost->nonIPTraffic != NULL)
       totTraffic.value += theHost->nonIPTraffic->stpRcvd.value
-	+theHost->nonIPTraffic->ipxRcvd.value
 	+theHost->nonIPTraffic->dlcRcvd.value
 	+theHost->nonIPTraffic->arp_rarpRcvd.value
-	+theHost->nonIPTraffic->appletalkRcvd.value
 	+theHost->nonIPTraffic->netbiosRcvd.value
 	+theHost->nonIPTraffic->otherRcvd.value;
     
@@ -250,11 +246,6 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "STP";
 	}
 
-	if(theHost->nonIPTraffic->ipxSent.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->ipxSent.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "IPX";
-	}
-
 	if(theHost->nonIPTraffic->dlcSent.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->dlcSent.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "DLC";
@@ -265,11 +256,6 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "(R)ARP";
 	}
 
-	if(theHost->nonIPTraffic->appletalkSent.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->appletalkSent.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "AppleTalk";
-	}
-
 	if(theHost->nonIPTraffic->netbiosSent.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->netbiosSent.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "NetBios";
@@ -319,11 +305,6 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "STP";
 	}
 
-	if(theHost->nonIPTraffic->ipxRcvd.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->ipxRcvd.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "IPX";
-	}
-
 	if(theHost->nonIPTraffic->dlcRcvd.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->dlcRcvd.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "DLC";
@@ -334,11 +315,6 @@ void hostTrafficDistrib(HostTraffic *theHost, short dataSent) {
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "(R)ARP";
 	}
 
-	if(theHost->nonIPTraffic->appletalkRcvd.value > 0) {
-	  p[num] = (float)((100*theHost->nonIPTraffic->appletalkRcvd.value)/totTraffic.value);
-	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "AppleTalk";
-	}
-
 	if(theHost->nonIPTraffic->netbiosRcvd.value > 0) {
 	  p[num] = (float)((100*theHost->nonIPTraffic->netbiosRcvd.value)/totTraffic.value);
 	  if(p[num] > MIN_SLICE_PERCENTAGE) lbl[num++] = "NetBios";
@@ -934,12 +910,8 @@ void drawGlobalProtoDistribution(void) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].arpRarpBytes.value; lbl[idx] = "(R)ARP"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].dlcBytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].dlcBytes.value; lbl[idx] = "DLC"; idx++; }
-  if(myGlobals.device[myGlobals.actualReportDeviceId].ipxBytes.value > 0) {
-    p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].ipxBytes.value; lbl[idx] = "IPX"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].ipsecBytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].ipsecBytes.value;lbl[idx] = "IPsec";  idx++; }
-  if(myGlobals.device[myGlobals.actualReportDeviceId].atalkBytes.value > 0) {
-    p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].atalkBytes.value; lbl[idx] = "AppleTalk"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].netbiosBytes.value > 0) {
     p[idx] = myGlobals.device[myGlobals.actualReportDeviceId].netbiosBytes.value; lbl[idx] = "NetBios"; idx++; }
   if(myGlobals.device[myGlobals.actualReportDeviceId].greBytes.value > 0) {
@@ -1078,495 +1050,3 @@ int drawHostsDistanceGraph(int checkOnly) {
 
 /* ************************ */
 
-#ifdef ENABLE_FC
-void hostFcTrafficDistrib(HostTraffic *theHost, short dataSent) {
-  float p[MAX_NUM_PROTOS];
-  char	*lbl[] = { "", "", "", "", "", "", "", "", "",
-		   "", "", "", "", "", "", "", "", "", "" };
-  int i, num=0, explodePieces[MAX_NUM_PROTOS];
-  TrafficCounter traffic, totalFcTraffic, diffTraffic;
-  char *lblstouse[] = { "SCSI", "FICON", "ELS", "NS", "IP/FC", "Others"};
-  Counter protoTrafficSent[] = {
-      theHost->fcCounters->fcFcpBytesSent.value,
-      theHost->fcCounters->fcFiconBytesSent.value,
-      theHost->fcCounters->fcElsBytesSent.value,
-      theHost->fcCounters->fcDnsBytesSent.value,
-      theHost->fcCounters->fcIpfcBytesSent.value,
-      theHost->fcCounters->otherFcBytesSent.value,
-  };
-
-  Counter protoTrafficRcvd[] = {
-      theHost->fcCounters->fcFcpBytesRcvd.value,
-      theHost->fcCounters->fcFiconBytesRcvd.value,
-      theHost->fcCounters->fcElsBytesRcvd.value,
-      theHost->fcCounters->fcDnsBytesRcvd.value,
-      theHost->fcCounters->fcIpfcBytesRcvd.value,
-      theHost->fcCounters->otherFcBytesRcvd.value,
-  };
-
-  totalFcTraffic.value = 0;
-  diffTraffic.value = 0;
-
-  if(dataSent)
-      totalFcTraffic.value = theHost->fcCounters->fcBytesSent.value;
-  else
-      totalFcTraffic.value = theHost->fcCounters->fcBytesRcvd.value;
-  
-  if(totalFcTraffic.value > 0) {
-      for (i = 0; i < 6; i++) {
-          if(dataSent) 
-              traffic.value = protoTrafficSent[i];
-          else 
-              traffic.value = protoTrafficRcvd[i];
-
-          if(traffic.value > 0) {
-              p[num] = (float)((100*traffic.value)/totalFcTraffic.value);
-              diffTraffic.value += traffic.value;
-
-              if(num == 0)
-                  explodePieces[num]=10;
-              else
-                  explodePieces[num]=explodePieces[num-1];
-              if (p[num]<5.0)
-                  explodePieces[num]+=9;
-              else if (p[num]>10.0)
-                  explodePieces[num]=10;
-              
-              lbl[num++] = lblstouse[i];
-          }
-      }
-  }
-
-  if(num == 1) p[0] = 100; /* just to be safe */
-  build_pie(num, p, lbl);
-}
-
-/* ********************************** */
-
-void fcPktSizeDistribPie(void) {
-  float p[10];
-  char	*lbl[] = { "", "", "", "", "", "", "", "", "", ""};
-  int num=0;
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo36.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo36.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 36";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo48.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo48.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 48";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo52.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo52.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 52";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo68.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo68.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 68";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo104.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo104.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 104";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo548.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo548.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 548";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo1060.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo1060.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 1060";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo2136.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.upTo2136.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "<= 2136";
-  };
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.above2136.value > 0) {
-    p[num] = (float)(100*myGlobals.device[myGlobals.actualReportDeviceId].rcvdFcPktStats.above2136.value)/
-      (float)myGlobals.device[myGlobals.actualReportDeviceId].ethernetPkts.value;
-    lbl[num++] = "> 2136";
-  };
-
-  if(num == 1) p[0] = 100; /* just to be safe */
-  build_pie(num, p, lbl);
-}
-
-/* ******************************** */
-
-void drawGlobalFcProtoDistribution(void) {
-  int idx=0;
-  float p[256];
-  char *lbl[256];
-
-  p[myGlobals.numIpProtosToMonitor] = 0;
-
-  if(myGlobals.device[myGlobals.actualReportDeviceId].fcFcpBytes.value) {
-      p[idx]  = (float)myGlobals.device[myGlobals.actualReportDeviceId].fcFcpBytes.value;
-      lbl[idx++] = "SCSI";
-  }
-
-  if (myGlobals.device[myGlobals.actualReportDeviceId].fcFiconBytes.value) {
-      p[idx] = (float)myGlobals.device[myGlobals.actualReportDeviceId].fcFiconBytes.value;
-      lbl[idx++] = "FICON";
-  }
-
-  if (myGlobals.device[myGlobals.actualReportDeviceId].fcElsBytes.value) {
-      p[idx] = (float)myGlobals.device[myGlobals.actualReportDeviceId].fcElsBytes.value;
-      lbl[idx++] = "ELS";
-  }
-
-  if (myGlobals.device[myGlobals.actualReportDeviceId].fcIpfcBytes.value) {
-      p[idx] = (float)myGlobals.device[myGlobals.actualReportDeviceId].fcIpfcBytes.value;
-      lbl[idx++] = "IP/FC";
-  }
-
-  if (myGlobals.device[myGlobals.actualReportDeviceId].fcDnsBytes.value) {
-      p[idx] = (float)myGlobals.device[myGlobals.actualReportDeviceId].fcDnsBytes.value;
-      lbl[idx++] = "NS";
-  }
-
-  if (myGlobals.device[myGlobals.actualReportDeviceId].fcSwilsBytes.value) {
-      p[idx] = (float)myGlobals.device[myGlobals.actualReportDeviceId].fcSwilsBytes.value;
-      lbl[idx++] = "SWILS";
-  }
-
-  if (myGlobals.device[myGlobals.actualReportDeviceId].otherFcBytes.value) {
-      p[idx] = (float)myGlobals.device[myGlobals.actualReportDeviceId].otherFcBytes.value;
-      lbl[idx++] = "Others";
-  }
-
-  build_bar(idx, p, lbl);
-}
-
-/* *******************************************************/
-
-void drawLunStatsBytesDistribution(HostTraffic *el) {
-  int lun, numEntries, idx=0;
-  float p[MAX_LUNS_GRAPHED+1];
-  char *lbl[MAX_LUNS_GRAPHED+1];
-  char label[MAX_LUNS_GRAPHED+1][10];
-  LunStatsSortedEntry sortedLunTbl[MAX_LUNS_SUPPORTED];
-  LunStatsSortedEntry *entry;
-  ScsiLunTrafficInfo *lunStats;
-
-  p[MAX_LUNS_GRAPHED] = 0;
-  numEntries = 0;
-
-  memset(sortedLunTbl, 0, sizeof (sortedLunTbl));
-
-  for (lun=0, numEntries=0; lun < MAX_LUNS_SUPPORTED; lun++) {
-    if ((lunStats = el->fcCounters->activeLuns[lun]) != NULL) {
-          sortedLunTbl[numEntries].lun = lun;
-          sortedLunTbl[numEntries++].stats = el->fcCounters->activeLuns[lun];
-      }
-  }
-
-  myGlobals.columnSort = 4;     /* This is based on total I/O */
-  qsort (sortedLunTbl, numEntries, sizeof (LunStatsSortedEntry), cmpLunFctn);
-
-  idx = 0;
-  for (lun = numEntries-1; ((idx < MAX_LUNS_GRAPHED) && (lun >= 0));
-       lun--) {
-      entry = &sortedLunTbl[lun];
-      p[idx] = (float) (entry->stats->bytesSent.value +
-                        entry->stats->bytesRcvd.value);
-      if (p[idx] > 0) {
-          safe_snprintf(__FILE__, __LINE__, label[idx], sizeof(label[idx]), "%hd", entry->lun);
-          lbl[idx] = label[idx];
-          idx++;
-      }
-  }
-  
-  build_bar(idx, p, lbl);
-}
-
-/* *******************************************************/
-
-void drawLunStatsPktsDistribution(HostTraffic *el) {
-  int lun, numEntries, idx=0;
-  float p[MAX_LUNS_GRAPHED+1];
-  char *lbl[MAX_LUNS_GRAPHED+1];
-  char label[MAX_LUNS_GRAPHED+1][10];
-  ScsiLunTrafficInfo *lunStats;
-  LunStatsSortedEntry sortedLunTbl[MAX_LUNS_SUPPORTED];
-  LunStatsSortedEntry *entry;
-
-  p[MAX_LUNS_GRAPHED] = 0;
-  numEntries = 0;
-
-  memset(sortedLunTbl, 0, sizeof (sortedLunTbl));
-
-  for (lun=0, numEntries=0; lun < MAX_LUNS_SUPPORTED; lun++) {
-      if ((lunStats = el->fcCounters->activeLuns[lun]) != NULL) {
-          sortedLunTbl[numEntries].lun = lun;
-          sortedLunTbl[numEntries++].stats = el->fcCounters->activeLuns[lun];
-      }
-  }
-
-  myGlobals.columnSort = 5;     /* This is based on total frames */
-  qsort (sortedLunTbl, numEntries, sizeof (LunStatsSortedEntry), cmpLunFctn);
-  
-  for (lun = numEntries-1; ((idx < MAX_LUNS_GRAPHED) && (lun >= 0));
-       lun--) {
-      entry = &sortedLunTbl[lun];
-      p[idx] = (float) (entry->stats->pktRcvd +
-                        entry->stats->pktSent);
-      if (p[idx] > 0) {
-          sprintf (label[idx],"%hd", entry->lun);
-          lbl[idx] = label[idx];
-          idx++;
-      }
-  }
-
-  build_bar(idx, p, lbl);
-}
-
-/* *******************************************************/
-
-void drawVsanStatsBytesDistribution(int deviceId) {
-  int numVsans, idx=0, i, j;
-  float p[MAX_VSANS_GRAPHED+1];
-  char *lbl[MAX_VSANS_GRAPHED+1];
-  char label[MAX_VSANS_GRAPHED+1][10];
-  FcFabricElementHash **theHash;
-  FcFabricElementHash *tmpTable[MAX_ELEMENT_HASH];
-  
-  if ((theHash = myGlobals.device[deviceId].vsanHash) == NULL) {
-      return;
-  }
-
-  p[MAX_VSANS_GRAPHED] = 0;
-  numVsans = 0;
-
-  memset (tmpTable, 0, sizeof (FcFabricElementHash *)*MAX_ELEMENT_HASH);
-  for (i=0; i<MAX_ELEMENT_HASH; i++) {
-      if((theHash[i] != NULL) && (theHash[i]->vsanId < MAX_HASHDUMP_ENTRY) &&
-         (theHash[i]->vsanId < MAX_USER_VSAN)) {
-          if (theHash[i]->totBytes.value)
-              tmpTable[numVsans++] = theHash[i];
-      }
-  }
-
-  if (!numVsans) {
-      printNoDataYet ();
-      return;
-  }
-  
-  myGlobals.columnSort = 3;
-  qsort (tmpTable, numVsans, sizeof (FcFabricElementHash **), cmpVsanFctn);
-  
-  idx = 0;
-  for (i = numVsans-1, j = 0; i >= 0; i--, j++) {
-      if (tmpTable[i] != NULL) {
-          p[idx] = tmpTable[i]->totBytes.value;
-          if (tmpTable[i]->vsanId) {
-              sprintf (label[idx], "%hd", tmpTable[i]->vsanId);
-          }
-          else {
-              sprintf (label[idx], "N/A");
-          }
-          lbl[idx] = label[idx];
-	  idx++;
-      }
-
-      if (j >= MAX_VSANS_GRAPHED)
-          break;
-  }
-
-  build_bar(idx, p, lbl);  
-}
-
-/* *******************************************************/
-
-void drawVsanStatsPktsDistribution(int deviceId) {
-  int numVsans, idx=0, i, j;
-  float p[MAX_VSANS_GRAPHED+1];
-  char *lbl[MAX_VSANS_GRAPHED+1];
-  char label[MAX_VSANS_GRAPHED+1][10];
-  FcFabricElementHash **theHash;
-  FcFabricElementHash *tmpTable[MAX_ELEMENT_HASH];
-  
-  if ((theHash = myGlobals.device[deviceId].vsanHash) == NULL) {
-      return;
-  }
-
-  p[MAX_VSANS_GRAPHED] = 0;
-  numVsans = 0;
-
-  memset (tmpTable, 0, sizeof (FcFabricElementHash *)*MAX_ELEMENT_HASH);
-  for (i=0; i<MAX_ELEMENT_HASH; i++) {
-      if((theHash[i] != NULL) && (theHash[i]->vsanId < MAX_HASHDUMP_ENTRY) &&
-         (theHash[i]->vsanId < MAX_USER_VSAN)) {
-          if (theHash[i]->totPkts.value)
-              tmpTable[numVsans++] = theHash[i];
-      }
-  }
-
-  if (!numVsans) {
-      printNoDataYet ();
-      return;
-  }
-  
-  myGlobals.columnSort = 4;
-  qsort (tmpTable, numVsans, sizeof (FcFabricElementHash **), cmpVsanFctn);
-  
-  idx = 0;
-  for (i = numVsans-1, j = 0; i >= 0; i--, j++) {
-      if (tmpTable[i] != NULL) {
-          p[idx] = tmpTable[i]->totPkts.value;
-          if (tmpTable[i]->vsanId) {
-              sprintf (label[idx], "%d", tmpTable[i]->vsanId);
-          }
-          else {
-              sprintf (label[idx], "N/A");
-          }
-	  
-          lbl[idx] = label[idx];
-	  idx++;
-      }
-
-      if (j >= MAX_VSANS_GRAPHED)
-          break;
-  }
-
-  build_bar(idx, p, lbl);
-}
-
-/* *******************************************************/
-
-void drawVsanSwilsProtoDistribution(u_short vsanId) {
-  int idx=0;
-  FcFabricElementHash *hash;
-  float p[256];
-  char *lbl[256];
-
-  p[myGlobals.numIpProtosToMonitor] = 0;
-
-  hash = getFcFabricElementHash (vsanId, myGlobals.actualReportDeviceId);
-  
-  p[0] = (float)hash->dmBytes.value;
-  if (p[0] > 0) {
-      p[myGlobals.numIpProtosToMonitor] += p[0];
-      lbl[idx++] = "DM";
-  }
-
-  p[1] = (float)hash->fspfBytes.value;
-  if (p[1] > 0) {
-      p[myGlobals.numIpProtosToMonitor] += p[1];
-      lbl[idx++] = "FSPF";
-  }
-
-  p[2] = (float)hash->nsBytes.value;
-  if (p[2] > 0) {
-      p[myGlobals.numIpProtosToMonitor] += p[2];
-      lbl[idx++] = "NS";
-  }
-
-  p[3] = (float)hash->zsBytes.value;
-  if (p[3] > 0) {
-      p[myGlobals.numIpProtosToMonitor] += p[3];
-      lbl[idx++] = "ZS";
-  }
-
-  p[4] = (float)hash->rscnBytes.value;
-  if (p[4] > 0) {
-      p[myGlobals.numIpProtosToMonitor] += p[4];
-      lbl[idx++] = "SW_RSCN";
-  }
-
-  p[5] = (float)hash->fcsBytes.value;
-  if (p[5] > 0) {
-      p[myGlobals.numIpProtosToMonitor] += p[5];
-      lbl[idx++] = "FCS";
-  }
-
-  p[6] = (float)hash->otherCtlBytes.value;
-  if (p[6] > 0) {
-      p[myGlobals.numIpProtosToMonitor] += p[6];
-      lbl[idx++] = "Others";
-  }
-
-  build_pie(idx, p, lbl);
-}
-
-/* *******************************************************/
-
-void drawVsanDomainTrafficDistribution(u_short vsanId, u_char dataSent) {
-  int i, idx=0, numEntries = 0;
-  FcFabricElementHash *hash;
-  float p[MAX_VSANS_GRAPHED+1] = { 0 };
-  char *lbl[MAX_VSANS_GRAPHED+1], labels[MAX_VSANS_GRAPHED+1][8];
-  Counter total;
-  SortedFcDomainStatsEntry *fcDomainStats;
-
-  hash = getFcFabricElementHash (vsanId, myGlobals.actualReportDeviceId);
-
-  if (hash == NULL) {
-      printNoDataYet();
-      return;
-  }
-
-  fcDomainStats = (SortedFcDomainStatsEntry *)malloc (MAX_FC_DOMAINS*sizeof (SortedFcDomainStatsEntry));
-  if (fcDomainStats == NULL) {
-      traceEvent (CONST_TRACE_WARNING, "Unable to allocate memory for SortedFcDomainStatsEntry\n");
-      printNoDataYet();
-      return;
-  }
-  memset (fcDomainStats, 0, MAX_FC_DOMAINS*sizeof (SortedFcDomainStatsEntry));
-  
-  for (i = 1; i < MAX_FC_DOMAINS; i++) {
-      if (dataSent) {
-          if (hash->domainStats[i].sentBytes.value) {
-              fcDomainStats[numEntries].domainId = i;
-              fcDomainStats[numEntries++].stats = &hash->domainStats[i];
-          }
-      }
-      else {
-          if (hash->domainStats[i].rcvdBytes.value) {
-              fcDomainStats[numEntries].domainId = i;
-              fcDomainStats[numEntries++].stats = &hash->domainStats[i];
-          }
-      }
-  }
-
-  if (numEntries == 0) {
-      printNoDataYet();
-      return;
-  }
-
-  myGlobals.columnSort = dataSent;
-  qsort(fcDomainStats, numEntries, sizeof (SortedFcDomainStatsEntry), cmpFcDomainFctn);
-  
-  for (i = numEntries-1; (idx < MAX_VSANS_GRAPHED) && (i >= 0); i--) {
-      if (dataSent) {
-          total = fcDomainStats[i].stats->sentBytes.value;
-      }
-      else {
-          total = fcDomainStats[i].stats->rcvdBytes.value;
-      }
-      if (total > 0) {
-          p[idx] = (float)total;
-          sprintf (labels[idx], "%x", fcDomainStats[i].domainId);
-          lbl[idx] = labels[idx];
-          idx++;
-      }
-  }
-
-  build_pie(idx, p, lbl);
-}
-#endif /* ENABLE_FC */
