@@ -1,8 +1,8 @@
 /*
  * -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
- *                          http://www.ntop.org
+ *                          HutuBttp://www.ntop.org
  *
- * Copyright (C) 1998-2010 Luca Deri <deri@ntop.org>
+ * Copyright (C) 1998-2011 Luca Deri <deri@ntop.org>
  *
  * -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
  *
@@ -254,36 +254,14 @@ void resetDevice(int devIdx, short fullReset) {
   resetTrafficCounter(&myGlobals.device[devIdx].otherIpBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].icmpBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].dlcBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].ipxBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].stpBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].ipsecBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].netbiosBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].arpRarpBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].atalkBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].egpBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].greBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].ipv6Bytes);
   resetTrafficCounter(&myGlobals.device[devIdx].otherBytes);
-#ifdef ENABLE_FC
-  resetTrafficCounter(&myGlobals.device[devIdx].fcBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fragmentedFcBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcFcpBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcFiconBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcIpfcBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcSwilsBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcDnsBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcElsBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].otherFcBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].class2Bytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].class3Bytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].classFBytes);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcPkts);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcEofaPkts);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcEofAbnormalPkts);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcAbnormalPkts);
-  resetTrafficCounter(&myGlobals.device[devIdx].fcBroadcastPkts);
-  memset(&myGlobals.device[devIdx].rcvdFcPktStats, 0, sizeof(FcPacketStats));
-#endif
   resetTrafficCounter(&myGlobals.device[devIdx].lastMinEthernetBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].lastFiveMinsEthernetBytes);
   resetTrafficCounter(&myGlobals.device[devIdx].lastMinEthernetPkts);
@@ -365,7 +343,6 @@ void initCounters(void) {
 
   setDomainName();
 
-#ifdef INET6
   _in6addr_linklocal_allnodes.s6_addr[0] = 0xff;
   _in6addr_linklocal_allnodes.s6_addr[1] = 0x02;
   _in6addr_linklocal_allnodes.s6_addr[2] = 0x00;
@@ -382,7 +359,6 @@ void initCounters(void) {
   _in6addr_linklocal_allnodes.s6_addr[13] = 0x00;
   _in6addr_linklocal_allnodes.s6_addr[14] = 0x00;
   _in6addr_linklocal_allnodes.s6_addr[15] = 0x01;
-#endif
 
   memset(myGlobals.transTimeHash, 0, sizeof(myGlobals.transTimeHash));
   memset(myGlobals.dummyEthAddress, 0, LEN_ETHERNET_ADDRESS);
@@ -395,38 +371,16 @@ void initCounters(void) {
       len = sizeof(IPSession*)*MAX_TOT_NUM_SESSIONS;
       myGlobals.device[i].tcpSession = (IPSession**)malloc(len);
       memset(myGlobals.device[i].tcpSession, 0, len);
-
-#ifdef ENABLE_FC
-      len = sizeof(FCSession *)*MAX_TOT_NUM_SESSIONS;
-      myGlobals.device[i].fcSession = (FCSession **)malloc(len);
-      memset(myGlobals.device[i].fcSession, 0, len);
-#endif
     } else {
       myGlobals.device[i].tcpSession     = NULL;
-#ifdef ENABLE_FC
-      myGlobals.device[i].fcSession      = NULL;
-#endif
     }
 
     myGlobals.device[i].fragmentList = NULL;
   }
 
-  myGlobals.ipxsapHashLoadCollisions = 0;
   myGlobals.hashCollisionsLookup     = 0;
 
-#ifdef ENABLE_FC
-  myGlobals.numVendorLookupRead = 0;
-  myGlobals.numVendorLookupAdded = 0;
-  myGlobals.numVendorLookupAddedSpecial = 0;
-  myGlobals.numVendorLookupCalls = 0;
-  myGlobals.numVendorLookupSpecialCalls = 0;
-  myGlobals.numVendorLookupFound48bit = 0;
-  myGlobals.numVendorLookupFound24bit = 0;
-  myGlobals.numVendorLookupFoundMulticast = 0;
-  myGlobals.numVendorLookupFoundLAA = 0;
-#endif
-
-  if (myGlobals.pcap_file_list == NULL)
+  if(myGlobals.pcap_file_list == NULL)
     myGlobals.initialSniffTime = myGlobals.lastRefreshTime = time(NULL);  
   else
     myGlobals.initialSniffTime = 0; /* We set the start when first pkt is
@@ -467,15 +421,11 @@ void initCounters(void) {
 
 void resetStats(int deviceId) {
   u_int j;
-#ifdef ENABLE_FC
-  int i;
-  FCSession *session;
-#endif
 
   traceEvent(CONST_TRACE_INFO, "Resetting traffic statistics for device %s",
 	     myGlobals.device[deviceId].humanFriendlyName);
 
-  if(myGlobals.purgeMutex.isInitialized != 0)
+  if(myGlobals.purgeMutex.isInitialized)
     accessMutex(&myGlobals.purgeMutex, "resetStats");
 
   for(j=FIRST_HOSTS_ENTRY; j<myGlobals.device[deviceId].actualHashSize; j++) {
@@ -510,28 +460,7 @@ void resetStats(int deviceId) {
 	myGlobals.device[deviceId].tcpSession[j] = NULL;
       }
   }
-
-#ifdef ENABLE_FC
-  if(myGlobals.device[deviceId].fcSession != NULL) {
-    for(j=0; j<MAX_TOT_NUM_SESSIONS; j++)
-      if((session = myGlobals.device[deviceId].fcSession[j]) != NULL) {
-          for(i = 0; i < MAX_LUNS_SUPPORTED; i++) {
-	    if(session->activeLuns[i] != NULL) {
-	      free (session->activeLuns[i]);
-	    }
-          }
-          free(session);
-          myGlobals.device[deviceId].fcSession[j] = NULL;
-      }
-  }
-
-  /* Free VSAN Hash */
-  if (myGlobals.device[deviceId].vsanHash != NULL) {
-      free (myGlobals.device[deviceId].vsanHash);
-      myGlobals.device[deviceId].vsanHash = NULL;
-  }
-#endif
-
+  
   myGlobals.device[deviceId].hash_hostTraffic[BROADCAST_HOSTS_ENTRY] = myGlobals.broadcastEntry;
   myGlobals.broadcastEntry->hostSerial.serialType = SERIAL_IPV4;
   myGlobals.broadcastEntry->hostSerial.value.ipSerial.ipAddress.Ip4Address.s_addr = -1;
@@ -679,8 +608,7 @@ void reinitMutexes (void) {
   for(i=0; i<NUM_SESSION_MUTEXES; i++)
     createMutex(&myGlobals.tcpSessionsMutex[i]); /* data to synchronize TCP sessions access */
 
-  createMutex(&myGlobals.fcSessionsMutex);
-  createMutex(&myGlobals.purgePortsMutex);  /* data to synchronize port purge access */
+    createMutex(&myGlobals.purgePortsMutex);  /* data to synchronize port purge access */
   createMutex(&myGlobals.purgePortsMutex);  /* data to synchronize port purge access */
 
   for(i=0; i<CONST_HASH_INITIAL_SIZE; i++) {
@@ -704,22 +632,11 @@ void initThreads(void) {
   int i;
 
   /*
-    for(i=0; i<myGlobals.numDevices; i++) {
-    createThread(&myGlobals.device[i].dequeuePacketThreadId, dequeuePacket, (void*)((long)i));
-    traceEvent(CONST_TRACE_INFO, "THREADMGMT[t%lu]: NPA: Started thread for network packet analyzer (%s)",
-    (long)myGlobals.device[i].dequeuePacketThreadId,
-    myGlobals.device[i].humanFriendlyName);
-    }
-  */
-
-  if(!myGlobals.runningPref.liveMode) {
-    /*
-     * Create the thread (3) - SFP - Scan Fingerprints
-     */
-    createThread(&myGlobals.scanFingerprintsThreadId, scanFingerprintLoop, NULL);
-    traceEvent(CONST_TRACE_INFO, "THREADMGMT[t%lu]: SFP: Started thread for fingerprinting",
-	       (long)myGlobals.scanFingerprintsThreadId);
-  }
+   * Create the thread (3) - SFP - Scan Fingerprints
+   */
+  createThread(&myGlobals.scanFingerprintsThreadId, scanFingerprintLoop, NULL);
+  traceEvent(CONST_TRACE_INFO, "THREADMGMT[t%lu]: SFP: Started thread for fingerprinting",
+	     (long)myGlobals.scanFingerprintsThreadId);
 
   /*
    * Create the thread (4) - SIH - Scan Idle Hosts - optional
@@ -808,7 +725,7 @@ void allocDeviceMemory(int deviceId) {
  * if device is "none" it adds a dummy interface
  */
 void addDevice(char* deviceName, char* deviceDescr) {
-  int i, deviceId, mallocLen, memlen;
+  int i, deviceId, mallocLen;
   char *workDevices = NULL;
   char myName[255], *column = NULL, ebuf[CONST_SIZE_PCAP_ERR_BUF], tmpStr[64];
 
@@ -901,20 +818,12 @@ void addDevice(char* deviceName, char* deviceDescr) {
     }
 #endif
 
-    if(myGlobals.runningPref.printIpOnly) {
-      myGlobals.device[deviceId].pcapPtr =
-	pcap_open_live(myGlobals.device[deviceId].name,
-		       myGlobals.runningPref.enablePacketDecoding == 0 ? 68 : DEFAULT_SNAPLEN,
-		       myGlobals.runningPref.disablePromiscuousMode == 1 ? 0 : 1,
-		       1000 /* ms */, ebuf);
-    }
-    else {
-        myGlobals.device[deviceId].pcapPtr =
-	pcap_open_live(myGlobals.device[deviceId].name,
-		       MAX_PACKET_LEN,
-		       myGlobals.runningPref.disablePromiscuousMode == 1 ? 0 : 1,
-		       1000 /* ms */, ebuf);
-    }
+    
+    myGlobals.device[deviceId].pcapPtr =
+      pcap_open_live(myGlobals.device[deviceId].name,
+		     MAX_PACKET_LEN,
+		     myGlobals.runningPref.disablePromiscuousMode == 1 ? 0 : 1,
+		     1000 /* ms */, ebuf);    
 
       if(myGlobals.device[deviceId].pcapPtr == NULL) {
 	traceEvent(CONST_TRACE_ERROR, "pcap_open_live(): '%s'", ebuf);
@@ -1023,7 +932,7 @@ void addDevice(char* deviceName, char* deviceDescr) {
     } else {
       myGlobals.device[deviceId].numHosts = 0xFFFFFFFF - myGlobals.device[deviceId].netmask.s_addr + 1;
 
-      /* Add some room for multicast hosts in the ipTrafficMatrix
+      /* Add some room for multicast hosts
        * This is an arbitrary guess.
        * We use the log function to limit growth for large networks, while the factor of 50
        * is designed to ensure a certain minimal # even for smaller networks
@@ -1043,69 +952,20 @@ void addDevice(char* deviceName, char* deviceDescr) {
 		 intoa(myGlobals.device[deviceId].netmask),
 		 myGlobals.device[deviceId].numHosts);
     }
-
-    if(myGlobals.runningPref.liveMode) {
-      myGlobals.device[deviceId].ipTrafficMatrix = NULL;
-    } else {
-      memlen = sizeof(TrafficEntry*)*myGlobals.device[deviceId].numHosts*myGlobals.device[deviceId].numHosts;
-      myGlobals.device[deviceId].ipTrafficMatrix = (TrafficEntry**)calloc(myGlobals.device[deviceId].numHosts
-									  *myGlobals.device[deviceId].numHosts,
-									  sizeof(TrafficEntry*));
-      if(myGlobals.device[deviceId].ipTrafficMatrix == NULL) {
-	traceEvent(CONST_TRACE_FATALERROR, "Memory allocation (%d bytes) for ipTraffixMatrix failed", memlen);
-	exit(12); /* Just in case */
-      }
-
-      traceEvent(CONST_TRACE_NOISY, "MEMORY: ipTrafficMatrix base (no TrafficEntry) for interface '%s' is %5.2fMB",
-		 myGlobals.device[deviceId].name,
-		 ((float)(memlen)/(float)(1024.0*1024.0))+0.05);
-      myGlobals.ipTrafficMatrixMemoryUsage += memlen;
-
-      memlen = sizeof(struct hostTraffic*)*myGlobals.device[deviceId].numHosts;
-      myGlobals.device[deviceId].ipTrafficMatrixHosts = (struct hostTraffic**)calloc(sizeof(struct hostTraffic*),
-										     myGlobals.device[deviceId].numHosts);
-
-      if(myGlobals.device[deviceId].ipTrafficMatrixHosts == NULL) {
-	traceEvent(CONST_TRACE_FATALERROR, "Memory allocation (%d bytes) for ipTraffixMatrixHosts failed", memlen);
-	exit(13); /* Just in case */
-      }
-
-      /* Allocate FC Traffic Matrices */
-#ifdef NOT_YET
-      if (!myGlobals.runningPref.printIpOnly) {
-        memlen = sizeof(TrafficEntry*)*myGlobals.device[deviceId].numHosts*myGlobals.device[deviceId].numHosts;
-        myGlobals.device[deviceId].fcTrafficMatrix = (TrafficEntry**)calloc(myGlobals.device[deviceId].numHosts
-                                                                            *myGlobals.device[deviceId].numHosts,
-                                                                            sizeof(TrafficEntry*));
-        if(myGlobals.device[deviceId].fcTrafficMatrix == NULL) {
-          traceEvent(CONST_TRACE_FATALERROR, "Memory allocation (%d bytes) for fcTraffixMatrix failed", memlen);
-          exit(14); /* Just in case */
-        }
-        myGlobals.fcTrafficMatrixMemoryUsage += memlen;
-
-        memlen = sizeof(struct hostTraffic*)*myGlobals.device[deviceId].numHosts;
-        myGlobals.device[deviceId].fcTrafficMatrixHosts = 
-	  (struct hostTraffic**)calloc(sizeof(struct hostTraffic*),
-				       myGlobals.device[deviceId].numHosts);
-      }
-#endif
-    }
   }
 
   /* ********************************************* */
 
-  if(!(myGlobals.device[deviceId].dummyDevice || myGlobals.device[deviceId].virtualDevice)){
+  if(!(myGlobals.device[deviceId].dummyDevice || myGlobals.device[deviceId].virtualDevice)) {
     u_int8_t netmask_v6;
     
     getLocalHostAddress(&myGlobals.device[deviceId].ifAddr, &netmask_v6, myGlobals.device[deviceId].name);
-#ifdef INET6
     myGlobals.device[deviceId].v6Addrs = getLocalHostAddressv6(myGlobals.device[deviceId].v6Addrs, 
 							       myGlobals.device[deviceId].name);
-#endif
-
 	if(myGlobals.device[deviceId].network.s_addr == 0) {
 		myGlobals.device[deviceId].netmask.s_addr = 0xFFFFFF00;/* /24 */
-		myGlobals.device[deviceId].network.s_addr = myGlobals.device[deviceId].ifAddr.s_addr & myGlobals.device[deviceId].netmask.s_addr;
+		myGlobals.device[deviceId].network.s_addr = myGlobals.device[deviceId].ifAddr.s_addr 
+		  & myGlobals.device[deviceId].netmask.s_addr;
 	}
   }
 
@@ -1590,26 +1450,6 @@ u_int createDummyInterface(char *ifName) {
     myGlobals.otherHostEntry->next = NULL;
   }
 
-#ifdef NOT_YET
-  mallocLen = sizeof(TrafficEntry*)*myGlobals.device[deviceId].numHosts*myGlobals.device[deviceId].numHosts;
-  myGlobals.device[deviceId].fcTrafficMatrix = (TrafficEntry**)calloc(myGlobals.device[deviceId].numHosts
-                                                                      *myGlobals.device[deviceId].numHosts,
-                                                                      sizeof(TrafficEntry*));
-  if(myGlobals.device[deviceId].fcTrafficMatrix == NULL) {
-      traceEvent(CONST_TRACE_FATALERROR, "Memory allocation (%d bytes) for fcTraffixMatrix failed", mallocLen);
-      exit(16); /* Just in case */
-  }
-
-  mallocLen = sizeof(struct hostTraffic*)*myGlobals.device[deviceId].numHosts;
-  myGlobals.device[deviceId].fcTrafficMatrixHosts = (struct hostTraffic**)calloc(sizeof(struct hostTraffic*),
-                                                                                 myGlobals.device[deviceId].numHosts);
-
-  if(myGlobals.device[deviceId].fcTrafficMatrixHosts == NULL) {
-      traceEvent(CONST_TRACE_FATALERROR, "Memory allocation (%d bytes) for fcTrafficMatrixHosts failed", mallocLen);
-      exit(17); /* Just in case */
-  }
-#endif
-
   /* Allocate memory for dhcp stats */
   for(i=0; i<myGlobals.numKnownSubnets; i++) {
     myGlobals.device[deviceId].networkHost[i].protocolInfo = calloc(1, sizeof(ProtocolInfo));
