@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1998-2010 Luca Deri <deri@ntop.org>
+ *  Copyright (C) 1998-2011 Luca Deri <deri@ntop.org>
  *
  *  			    http://www.ntop.org/
  *
@@ -535,167 +535,6 @@ void updateThpt(int fullUpdate) {
   }
 }
 
-/* ******************************* */
-
-/* Check if a host can be potentially added the host matrix */
-int isMatrixHost(HostTraffic *host, int actualDeviceId) {
-  if((host->hostIpAddress.hostFamily == AF_INET) /* Only IPv4 addresses are used in the matrix */
-     && (deviceLocalAddress(&host->hostIpAddress, actualDeviceId, NULL, NULL) || multicastHost(host))
-     && (!broadcastHost(host)))
-    return(1);
-  else
-    return(0);
-}
-
-/* ******************************* */
-
-unsigned int matrixHostHash(HostTraffic *host, int actualDeviceId, int rehash) {
-  unsigned long hash = 0;
-#ifdef ENABLE_FC
-  char tmpBuf[80], *str;
-  int c;
-#endif
-
-  if(myGlobals.device[actualDeviceId].numHosts  == 0) return(0);
-
-  if (host->l2Family == FLAG_HOST_TRAFFIC_AF_ETH) {
-    if (host->hostIpAddress.hostFamily == AF_INET)
-      hash = host->hostIp4Address.s_addr;
-#ifdef INET6
-    else if (host->hostIpAddress.hostFamily == AF_INET6)
-      hash = *(u_int32_t *)&host->hostIp6Address.s6_addr[0];
-#endif
-  }
-#ifdef ENABLE_FC
-  else {
-    if (host->fcCounters->vsanId) {
-      hash ^= host->fcCounters->vsanId;
-      hash ^= host->fcCounters->hostFcAddress.domain;
-      hash ^= host->fcCounters->hostFcAddress.area;
-      hash ^= host->fcCounters->hostFcAddress.port;
-      safe_snprintf(__FILE__, __LINE__, tmpBuf, sizeof (tmpBuf), "%x.%x.%x.%x.%x", host->fcCounters->vsanId, 
-		  host->fcCounters->hostFcAddress.domain, host->fcCounters->hostFcAddress.area,
-		  host->fcCounters->hostFcAddress.port, hash);
-    } else {
-      safe_snprintf(__FILE__, __LINE__, tmpBuf, sizeof (tmpBuf), "%x.%x.%x.%x",
-		   host->fcCounters->hostFcAddress.domain, host->fcCounters->hostFcAddress.area,
-		   host->fcCounters->hostFcAddress.port, host);
-    }
-    str = tmpBuf;
-	
-    /* sdbm hash algorithm */
-    hash = 0;
-    while((c = *str++)) {
-      hash = c + (hash << 6) + (hash << 16) - hash;
-    }
-
-    /* Assuming that the numHosts for FC is always 1024, 1021 is nearest
-     * prime */
-    if (rehash) {
-      c = (5 - hash%5);
-      hash += c;
-    }
-  }
-#endif
- 
-  return((unsigned int)(hash) % myGlobals.device[actualDeviceId].numHosts);
-}
-
-/* ******************************* */
-
-void updateTrafficMatrix(HostTraffic *srcHost,
-			 HostTraffic *dstHost,
-			 TrafficCounter length, 
-			 int actualDeviceId) {
-
-  if(myGlobals.device[actualDeviceId].numHosts == 0) return;
-  
-  if(isMatrixHost(srcHost, actualDeviceId) 
-     && isMatrixHost(dstHost, actualDeviceId)) {
-    unsigned int a, b, id;    
-    
-    a = matrixHostHash(srcHost, actualDeviceId, 0), b = matrixHostHash(dstHost, actualDeviceId, 0);
-
-    myGlobals.device[actualDeviceId].ipTrafficMatrixHosts[a] = srcHost, 
-      myGlobals.device[actualDeviceId].ipTrafficMatrixHosts[b] = dstHost;
-
-    id = a*myGlobals.device[actualDeviceId].numHosts+b;
-    if(myGlobals.device[actualDeviceId].ipTrafficMatrix[id] == NULL)
-      myGlobals.device[actualDeviceId].ipTrafficMatrix[id] = (TrafficEntry*)calloc(1, sizeof(TrafficEntry));
-    incrementTrafficCounter(&myGlobals.device[actualDeviceId].ipTrafficMatrix[id]->bytesSent, length.value);
-    incrementTrafficCounter(&myGlobals.device[actualDeviceId].ipTrafficMatrix[id]->pktsSent, 1);
-
-    id = b*myGlobals.device[actualDeviceId].numHosts+a;
-    if(myGlobals.device[actualDeviceId].ipTrafficMatrix[id] == NULL)
-      myGlobals.device[actualDeviceId].ipTrafficMatrix[id] = (TrafficEntry*)calloc(1, sizeof(TrafficEntry));
-    incrementTrafficCounter(&myGlobals.device[actualDeviceId].ipTrafficMatrix[id]->bytesRcvd, length.value);
-    incrementTrafficCounter(&myGlobals.device[actualDeviceId].ipTrafficMatrix[id]->pktsRcvd, 1);
-  }
-}
-
-/* ************************ */
-
-#ifdef ENABLE_FC
-void updateFcTrafficMatrix(HostTraffic *srcHost,
-			   HostTraffic *dstHost,
-			   TrafficCounter length, 
-			   int actualDeviceId) {
-  unsigned int a, b, id;
-
-  a = matrixHostHash (srcHost, actualDeviceId, 0);
-  b = matrixHostHash (dstHost, actualDeviceId, 0);
-
-  if ((myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[a] != NULL) &&
-      (myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[a] != srcHost)) {
-    myGlobals.fcMatrixHashCollisions++;
-    a = matrixHostHash (srcHost, actualDeviceId, 1);
-    if ((myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[a] != NULL) &&
-	(myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[a] != srcHost)) {
-      traceEvent (CONST_TRACE_WARNING, "Unable to resolve conflict in matrix host hash for %s with %s\n",
-		  myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[a]->fcCounters->hostNumFcAddress,
-		  srcHost->fcCounters->hostNumFcAddress);
-      myGlobals.fcMatrixHashUnresCollisions++;
-      return;
-    }
-  }
-
-  if ((myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[b] != NULL) &&
-      (myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[b] != dstHost)) {
-    myGlobals.fcMatrixHashCollisions++;
-    b = matrixHostHash (dstHost, actualDeviceId, 1);
-    if ((myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[b] != NULL) &&
-	(myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[b] != dstHost)) {
-      traceEvent (CONST_TRACE_WARNING, "Unable to resolve conflict in matrix host hash for %s with %s\n",
-		  myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[b]->fcCounters->hostNumFcAddress,
-		  dstHost->fcCounters->hostNumFcAddress);
-      myGlobals.fcMatrixHashUnresCollisions++;
-      return;
-    }
-  }
-    
-  myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[a] = srcHost, 
-    myGlobals.device[actualDeviceId].fcTrafficMatrixHosts[b] = dstHost;
-
-  id = a*myGlobals.device[actualDeviceId].numHosts+b;
-  if (myGlobals.device[actualDeviceId].fcTrafficMatrix[id] == NULL) {
-    myGlobals.device[actualDeviceId].fcTrafficMatrix[id] = (TrafficEntry*)calloc(1, sizeof(TrafficEntry));
-    myGlobals.device[actualDeviceId].fcTrafficMatrix[id]->vsanId = srcHost->fcCounters->vsanId;
-  }
-    
-  incrementTrafficCounter(&myGlobals.device[actualDeviceId].fcTrafficMatrix[id]->bytesSent, length.value);
-  incrementTrafficCounter(&myGlobals.device[actualDeviceId].fcTrafficMatrix[id]->pktsSent, 1);
-
-  id = b*myGlobals.device[actualDeviceId].numHosts+a;
-  if(myGlobals.device[actualDeviceId].fcTrafficMatrix[id] == NULL) {
-    myGlobals.device[actualDeviceId].fcTrafficMatrix[id] = (TrafficEntry*)calloc(1, sizeof(TrafficEntry));
-    myGlobals.device[actualDeviceId].fcTrafficMatrix[id]->vsanId = dstHost->fcCounters->vsanId;
-  }
-    
-  incrementTrafficCounter(&myGlobals.device[actualDeviceId].fcTrafficMatrix[id]->bytesRcvd, length.value);
-  incrementTrafficCounter(&myGlobals.device[actualDeviceId].fcTrafficMatrix[id]->pktsRcvd, 1);
-}
-#endif
-
 /* ************************ */
 
 int isInitialHttpData(char* packetData) {
@@ -717,6 +556,24 @@ int isInitialHttpData(char* packetData) {
 
 /* ************************ */
 
+int isInitialSkypeData(char* packetData, int packetDataLen) {
+  int i, num_found = 0;
+  
+  if((packetDataLen < 16) || (packetData[2] != 0x02)) return(0);
+
+  for(i=0; i<16; i++) if(packetData[i] == 0x02) num_found++;
+
+  return((num_found == 1) ? 1 : 0);
+}
+
+/* ************************ */
+
+int isInitialEdonkeyData(char* packetData, int packetDataLen) {
+  return(0);  // TODO
+}
+
+/* ************************ */
+
 int isInitialSshData(char* packetData) {
   /* SSH-1.99-OpenSSH_2.1.1 */
   if(strncmp(packetData, "SSH-", 4) == 0)
@@ -820,3 +677,56 @@ void setHostCommunity(HostTraffic *el) {
     el->community = strdup(community);
 }
 
+/* ********************************** */
+
+u_short isP2P(HostTraffic *a) {
+  if((a != NULL)
+     && ((a->totContactedSentPeers > CONTACTED_PEERS_THRESHOLD) 
+	 || (a->totContactedRcvdPeers > CONTACTED_PEERS_THRESHOLD))) {
+    /* Now we need to check if this has really been a P2P server */
+    int i;
+
+    for(i=0; i<MAX_NUM_RECENT_PORTS; i++) {
+      if((a->recentlyUsedServerPorts[i] == -1) || (a->recentlyUsedClientPorts[i] == -1))
+	return(0); /* It's just a busy server */
+    }
+    
+    return(1);
+  } else
+    return(0);
+}
+
+/* ********************************** */
+
+char* httpSiteIcon(char *name, char *buf, u_int buf_len, u_short addName) {
+  int i, num_dot = 0;
+
+  if(name == NULL)
+    return("&nbsp;");
+
+  i = strlen(name);
+  while(i > 0) {
+    if(name[i] == '.') {
+      num_dot++;
+      if(num_dot == 2) {
+	i++;
+	break;
+      }
+    }
+
+    i--;
+  }
+  
+  if(addName)
+    safe_snprintf(__FILE__, __LINE__, buf, buf_len,
+		  "<IMG width=16 height=16 SRC=\"http://www.%s/favicon.ico\" BORDER=0>&nbsp;<A HREF=http://%s>%s</A>",
+		  &name[i], name, name);
+  else
+    safe_snprintf(__FILE__, __LINE__, buf, buf_len,
+		  "<IMG width=16 height=16 SRC=\"http://www.%s/favicon.ico\" BORDER=0>&nbsp;",
+		  &name[i]);
+  
+  return(buf);
+}
+
+
